pub struct PrefixHitEstimate {
pub overlap_bytes: usize,
pub total_bytes: usize,
}Expand description
Result of comparing the current context against the previous baseline.
Fields
overlap_bytes: usizeNumber of bytes in the longest common prefix between the current and previous canonical context.
total_bytes: usizeTotal canonical bytes of the current context.