pub struct ExtensionModelContextProjection { /* private fields */ }Implementations
Sourceimpl ExtensionModelContextProjection
impl ExtensionModelContextProjection
pub fn rebuild( entries: impl IntoIterator<Item = ExtensionDurableEntry>, ) -> Result<Self, ExtensionModelContextProjectionError>
pub fn items(&self) -> Vec<ExtensionModelContextItem>
pub fn into_items(self) -> Vec<ExtensionModelContextItem>
Sourcepub fn replace(
&self,
entries: impl IntoIterator<Item = ExtensionDurableEntry>,
) -> Result<(), ExtensionModelContextProjectionError>
pub fn replace( &self, entries: impl IntoIterator<Item = ExtensionDurableEntry>, ) -> Result<(), ExtensionModelContextProjectionError>
Replace the live branch projection while retaining all shared handles.
Sourcepub fn apply_to_request(&self, request: &mut NormalizedModelRequestDraft)
pub fn apply_to_request(&self, request: &mut NormalizedModelRequestDraft)
Add the de-duplicated model-visible projection to one normalized model request. This never mutates the persisted agent transcript.
Sourcepub fn compaction_messages(&self) -> Vec<AgentMessage>
pub fn compaction_messages(&self) -> Vec<AgentMessage>
Project the de-duplicated model-visible entries into one compaction-only message list. Private state and custom events never enter this list.